@@ -14,8 +14,13 @@
 
 from __future__ import print_function
 
+import sys
+if sys.version_info[0] == 2:
+    _next_method_name = 'next'
+else:
+    _next_method_name = '__next__'
+
 cmd = __import__("sys").modules["pymol.cmd"]
-import string
 import pymol
 from pymol import movie
 # legacy mappings, remove in PyMOL 2.0
@@ -70,6 +75,14 @@ _color_cycle = [
 
 _color_cycle_len = len(_color_cycle)
 
+class _verbose_cmd_proxy:
+    def __init__(self, cmd):
+        self.cmd = cmd
+    def __getattr__(self, name):
+        return getattr(self.cmd, name)
+    def set(self, name, value=1):
+        return self.cmd.set(name, value, quiet=0)
+
 def color_by_area(sele, mode="molecular", state=0, palette='rainbow', _self=cmd):
     """
 DESCRIPTION
@@ -103,7 +116,7 @@ ARGUMENTS
         _self.get_area(tmpSel, load_b=1)
         _self.spectrum("b", palette, tmpSel)
         _self.iterate(tmpSel, "l_a(color)", space={'l_a': l.append})
-        _self.alter(orgSel, "color=l_n()", space={'l_n': iter(l).__next__})
+        _self.alter(orgSel, "color=l_n()", space={'l_n': getattr(iter(l), _next_method_name)})
 
         _self.recolor(orgSel)
     finally:
@@ -356,7 +369,7 @@ def protein_assign_charges_and_radii(obj_name,_self=cmd):
     while not assign.formal_charges(obj_name,quiet=1,_self=_self):
         print(" WARNING: unrecognized or incomplete residues are being deleted:")
         cmd.iterate("(byres ("+obj_name+" and flag 23)) and flag 31",
-                        'print "  "+model+"/"+segi+"/"+chain+"/"+resn+"`"+resi+"/"',quiet=1)
+                        'print("  "+model+"/"+segi+"/"+chain+"/"+resn+"`"+resi+"/")',quiet=1)
         cmd.remove("byres ("+obj_name+" and flag 23)") # get rid of residues that weren't assigned
         assign.missing_c_termini(obj_name,quiet=1,_self=_self)
         
@@ -366,7 +379,7 @@ def protein_assign_charges_and_radii(obj_name,_self=cmd):
     if not assign.amber99(obj_name,quiet=1,_self=_self):
         print(" WARNING: some unassigned atoms are being deleted:")
         cmd.iterate("byres ("+obj_name+" and flag 23)",
-                        'print "  "+model+"/"+segi+"/"+chain+"/"+resn+"`"+resi+"/"+name+"? ["+elem+"]"',quiet=1)
+                        'print("  "+model+"/"+segi+"/"+chain+"/"+resn+"`"+resi+"/"+name+"? ["+elem+"]")',quiet=1)
         cmd.remove(obj_name+" and flag 23") # get rid of any atoms that weren't assigned
         
     # show the user what the net charges are...
@@ -379,7 +392,7 @@ def protein_assign_charges_and_radii(obj_name,_self=cmd):
 def protein_vacuum_esp(selection, mode=2, border=10.0, quiet = 1, _self=cmd):
     cmd=_self
 
-    if ((string.split(selection)!=[selection]) or
+    if (selection.split() != [selection] or
          selection not in cmd.get_names('objects')):
         print(" Error: must provide an object name")
         raise cmd.QuietException
@@ -550,7 +563,7 @@ def modernize_rendering(mode,_self=cmd):
     updates settings to improve rendering speed
     and quality.
     """
-    cmd=_self
+    cmd = _verbose_cmd_proxy(_self)
     
     cmd.set("max_ups",0)
 
@@ -563,7 +576,7 @@ def modernize_rendering(mode,_self=cmd):
     cmd.do("_ rebuild")
 
 def performance(mode,_self=cmd):
-    cmd=_self
+    cmd = _verbose_cmd_proxy(_self)
     mode = int(mode)
     if mode==0: # maximum quality
         cmd.set('line_smooth',1)
@@ -776,35 +789,17 @@ def cbc(selection='(all)',first_color=7,quiet=1,legacy=0,_self=cmd):
     '''
     Color all chains a different color
     '''
-    cmd=_self
-    if int(legacy):
-        c = first_color
-        for a in cmd.get_chains(selection):
-            if len(string.strip(a)):
-                if not quiet: print((" util.cbc: color %d,(chain %s)"%(c,a)))
-                cmd.color("%d"%c,"(chain %s and (%s))"%(a,selection),quiet=quiet)
-                c = c + 1
-            elif len(a): # note, PyMOL's selection language can't handle this right now
-                if not quiet: print((" util.cbc: color %d,(chain ' ')"%(c)))
-                cmd.color("%d"%c,"(chain '' and (%s))"%selection,quiet=quiet)
-                c = c + 1
-            else:
-                if not quiet: print((" util.cbc: color %d,(chain '')"%(c)))
-                cmd.color("%d"%c,"(chain '' and (%s))"%selection,quiet=quiet)
-                c = c + 1
-    else:
-        c = 0
-        for a in cmd.get_chains(selection):
-            if len(string.strip(a)):
-                if not quiet: print((" util.cbc: color %d,(chain %s)"%(_color_cycle[c],a)))
-                cmd.color(_color_cycle[c],"(chain %s and (%s))"%(a,selection),quiet=quiet)
-            elif len(a): # note, PyMOL's selection language can't handle this right now
-                if not quiet: print((" util.cbc: color %d,(chain ' ')"%(_color_cycle[c])))
-                cmd.color(_color_cycle[c],"(chain '' and (%s))"%selection,quiet=quiet)
-            else:
-                if not quiet: print((" util.cbc: color %d,(chain '')"%(_color_cycle[c])))
-                cmd.color(_color_cycle[c],"(chain '' and (%s))"%selection,quiet=quiet)
-            c = (c + 1) % _color_cycle_len
+    legacy = int(legacy)
+    for c, a in enumerate(_self.get_chains(selection)):
+        if len(a.split()) != 1:
+            a = '"' + a + '"'
+        if legacy:
+            color = c + int(first_color)
+        else:
+            color = _color_cycle[c % _color_cycle_len]
+        if not quiet:
+            print(" util.cbc: color %s, (chain %s)" % (color, a))
+        _self.color(color, "(chain %s and (%s))" % (a, selection), quiet=quiet)
         
 def color_objs(selection='(all)',quiet=1,_self=cmd):
     cmd=_self 
@@ -827,7 +822,7 @@ def color_deep(color, name='all', quiet=1, _self=cmd):
     from pymol.menu import rep_setting_lists
     _self.unset_deep([s for L in rep_setting_lists for (r, s) in L if s],
             name, updates=0, quiet=quiet)
-    _self.color(color, name, quiet=quiet, _self=_self)
+    _self.color(color, name, quiet=quiet)
 
 def chainbow(selection='(all)', palette="rainbow", quiet=1, _self=cmd):
     '''
@@ -845,7 +840,7 @@ color_chains = cbc
 sum_charge = sum_partial_charges
 
 def ray_shadows(mode,_self=cmd):
-    cmd=_self
+    cmd = _verbose_cmd_proxy(_self)
     # adjustment factors for new lighting model in 0.99
     if mode=='none':
         cmd.set('ray_shadow',0)
@@ -1702,3 +1697,32 @@ SEE ALSO
         _self.delete(sele)
 
     return resarea
+
+
+def ligand_zoom(step=1, _self=cmd):
+    '''
+DESCRIPTION
+
+    Zoom to the next organic molecule (by residue identifier)
+
+    Bound to CTRL-L key.
+    '''
+    global _current_ligand
+
+    s = {'ligand_set': set()}
+    if _self.iterate('organic', 'ligand_set.add((model,segi,chain,resi))',
+            space=s) < 1:
+        return
+
+    ligands = sorted(s["ligand_set"])
+
+    try:
+        i = ligands.index(_current_ligand)
+    except (ValueError, NameError):
+        i = -1
+
+    i = (i + int(step)) % len(ligands)
+    _current_ligand = ligands[i]
+
+    # use "do" for feedback
+    _self.do('zoom /%s/%s/%s & resi %s, animate=1, buffer=2' % ligands[i])
