@@ -12,31 +12,36 @@
 #-*
 #Z* -------------------------------------------------------------------
 
+from __future__ import print_function, absolute_import
+
 if __name__=='pymol.viewing':
 
-    import thread
+    import sys
+    if sys.version_info[0] == 2:
+        import thread
+    else:
+        import _thread as thread
+
     import threading
-    import string
     import types
     import traceback
     import pymol
-    import selector
+    from . import selector
     import copy
-    import parsing
+    from . import parsing
     import re
-    import cmd
+    cmd = sys.modules["pymol.cmd"]
     
-    from cmd import _cmd,lock,unlock,Shortcut,QuietException,_raising, \
+    from .cmd import _cmd,lock,unlock,Shortcut,QuietException,_raising, \
           _feedback,fb_module,fb_mask, \
           repres,repres_sc, is_string, is_list, is_ok, is_error, \
+          repmasks,repmasks_sc, \
           toggle_dict,toggle_sc,stereo_dict,stereo_sc, \
           palette_dict, palette_sc, window_dict, window_sc, \
           safe_list_eval, safe_alpha_list_eval, \
           location_code, location_sc, boolean_dict, boolean_sc, \
           DEFAULT_ERROR, DEFAULT_SUCCESS
         
-    import thread
-
     palette_colors_dict = {
         'rainbow_cycle'     : 'magenta blue cyan green yellow orange red magenta',
         'rainbow_cycle_rev' : 'magenta red orange yellow green cyan blue magenta',
@@ -478,6 +483,13 @@ SEE ALSO
         if _self._raising(r,_self): raise QuietException            
         return r
 
+    def _rep_to_repmask(rep):
+        repn = 0
+        for rep in rep.split():
+            rep = repmasks_sc.auto_err(rep, 'representation')
+            repn |= repmasks[rep]
+        return repn
+
     def toggle(representation="lines", selection="all", _self=cmd):
         '''
 DESCRIPTION
@@ -514,9 +526,7 @@ SEE ALSO
             if representation == 'object':
                 repn = -2
             else:
-                rep = representation
-                rep = repres_sc.auto_err(rep,'representation')
-                repn = repres[rep];
+                repn = _rep_to_repmask(representation)
                 # preprocess selection 
                 selection = selector.process(selection)
             r = _cmd.toggle(_self._COb,str(selection),int(repn));
@@ -525,7 +535,23 @@ SEE ALSO
         if _self._raising(r,_self): raise QuietException
         return r
 
-    def show(representation="", selection="", _self=cmd):
+    def _showhide(rep, selection, value, _self):
+        if not selection and (rep in ("", "all") or '(' in rep or '/' in rep):
+            # rep looks like a selection
+            selection = rep
+            rep = "wire" if value else "everything"
+
+        selection = selector.process(selection) or "all"
+        repn = _rep_to_repmask(rep)
+        r = DEFAULT_ERROR
+
+        with _self.lockcm:
+            r = _cmd.showhide(_self._COb, str(selection), int(repn), value)
+
+        if _self._raising(r,_self): raise QuietException
+        return r
+
+    def show(representation="wire", selection="", _self=cmd):
         '''
 DESCRIPTION
 
@@ -560,40 +586,9 @@ SEE ALSO
     hide, enable, disable
 
 '''
-        r = DEFAULT_ERROR
-        try:
-            _self.lock(_self)
-            if (representation=="") and (selection==""):
-                if is_ok(_cmd.showhide(_self._COb,"(all)",repres['lines'],1)): # show lines by default
-                    r = _cmd.showhide(_self._COb,"(all)",repres['nonbonded'],2)
-            elif (representation!="") and (selection!=""):
-                rep = representation
-                rep = repres_sc.auto_err(rep,'representation')
-                repn = repres[rep];
-                # preprocess selection 
-                selection = selector.process(selection)
-                #   
-                r = _cmd.showhide(_self._COb,str(selection),int(repn),1);
-            elif representation=='all':
-                if is_ok(_cmd.showhide(_self._COb,"all",repres['lines'],1)): # show lines by default
-                    r = _cmd.showhide(_self._COb,"all",repres['nonbonded'], 1) # nonbonded
-            elif (representation[0:1]=='(') or (string.find(representation,'/')>=0):
-                # preprocess selection
-                selection = selector.process(representation)
-                #                  
-                if is_ok(_cmd.showhide(_self._COb,str(selection),repres['lines'],1)):
-                    r = _cmd.showhide(_self._COb,str(selection),repres['nonbonded'],2);
-            else: # selection==""
-                rep = representation
-                rep = repres_sc.auto_err(rep,'representation')
-                repn = repres[rep]
-                r = _cmd.showhide(_self._COb,"all",int(repn),1);
-        finally:
-            _self.unlock(r,_self)
-        if _self._raising(r,_self): raise QuietException         
-        return r
+        return _showhide(representation, selection, 1, _self)
 
-    def show_as(representation="", selection="", _self=cmd):
+    def show_as(representation="wire", selection="", _self=cmd):
         '''
 DESCRIPTION
 
@@ -631,53 +626,9 @@ SEE ALSO
 
     show, hide, enable, disable
         '''
-        r = DEFAULT_ERROR
-        try:
-            _self.lock(_self)
-            vis_sel = None
-            if (representation=="") and (selection==""):
-                if is_ok(_cmd.showhide(_self._COb,str(selection),-1,0)):
-                    if is_ok(_cmd.showhide(_self._COb,"(all)",repres['lines'],1)):
-                        r = _cmd.showhide(_self._COb,"(all)",repres['nonbonded'],1)
-            elif (representation!="") and (selection!=""):
-                rep = representation
-                rep = repres_sc.auto_err(rep,'representation')
-                repn = repres[rep]
-                # preprocess selection 
-                selection = selector.process(selection)
+        return _showhide(representation, selection, 2, _self)
 
-                # user specified 'visible' -- this has always been problematic
-
-                if "visible".startswith(selection.lower()) and len(string.split(selection))==1:
-                    vis_sel = _self.get_unused_name("_vis")
-                    _self.select(vis_sel, selection)
-                    selection = vis_sel
-
-                if is_ok(_cmd.showhide(_self._COb,str(selection),-1,0)):
-                    r = _cmd.showhide(_self._COb,str(selection),int(repn),1)
-            elif representation=='all':
-                if is_ok(_cmd.showhide(_self._COb,str(selection),-1,0)):            
-                    if if_ok(_cmd.showhide(_self._COb,"all",repres['lines'],1)): # show lines by default
-                        r = _cmd.showhide(_self._COb,"all",repres['nonbonded'],1) # show nonbonded by default
-            elif (representation[0:1]=='(') or (string.find(representation,'/')>=0):
-                # preprocess selection
-                selection = selector.process(representation)
-                if is_ok(_cmd.showhide(_self._COb,str(selection),-1,0)):
-                    r = _cmd.showhide(_self._COb,str(selection),repres['lines'],1)
-            else: # selection==""
-                rep = representation
-                rep = repres_sc.auto_err(rep,'representation')
-                repn = repres[rep];
-                if is_ok(_cmd.showhide(_self._COb,"all",-1,0)):
-                    r = _cmd.showhide(_self._COb,"all",int(repn),1);
-        finally:
-            if vis_sel is not None:
-                _self.delete(vis_sel)
-            _self.unlock(r,_self)
-        if _self._raising(r,_self): raise QuietException
-        return r
-
-    def hide(representation="", selection="",_self=cmd):
+    def hide(representation="everything", selection="",_self=cmd):
         '''
 DESCRIPTION
 
@@ -711,31 +662,7 @@ SEE ALSO
     show, enable, disable
 
         '''
-        r = DEFAULT_ERROR
-        try:
-            _self.lock(_self)
-            if (representation=="") and (selection==""):
-                r = _cmd.showhide(_self._COb,"@",0,0);      
-            elif (representation!="") and (selection!=""):
-                rep = representation
-                rep = repres_sc.auto_err(rep,'representation')
-                repn = repres[rep];
-                selection = selector.process(selection)
-                r = _cmd.showhide(_self._COb,str(selection),int(repn),0);
-            elif (representation=='all'):
-                r = _cmd.showhide(_self._COb,"@",0,0);
-            elif (representation[0:1]=='(') or (string.find(representation,'/')>=0):
-                selection = selector.process(representation)
-                r = _cmd.showhide(_self._COb,str(selection),-1,0);
-            else: # selection == ""
-                rep = representation
-                rep = repres_sc.auto_err(rep,'representation')
-                repn = repres[rep];
-                r = _cmd.showhide(_self._COb,"all",int(repn),0);
-        finally:
-            _self.unlock(r,_self)
-        if _self._raising(r,_self): raise QuietException         
-        return r
+        return _showhide(representation, selection, 0, _self)
 
 
     def get_view(output=1, quiet=1, _self=cmd):
@@ -800,10 +727,11 @@ SEE ALSO
         finally:
             _self.unlock(r,_self)
         if is_ok(r):
+            output = int(output)
             if len(r):
                 if (_self.get_setting_int("logging") != 0) and (output<3):
                     if not quiet:
-                        print " get_view: matrix written to log file."
+                        print(" get_view: matrix written to log file.")
                     _self.log("_ set_view (\\\n","cmd.set_view((\\\n")
                     _self.log("_  %14.9f, %14.9f, %14.9f,\\\n"%r[0:3]  ,
                               "  %14.9f, %14.9f, %14.9f,\\\n"%r[0:3])
@@ -820,15 +748,15 @@ SEE ALSO
                     if output<2: # suppress if we have a log file open
                         output=0
                 if output and (not quiet) and (output<3):
-                    print "### cut below here and paste into script ###"
-                    print "set_view (\\"
-                    print "  %14.9f, %14.9f, %14.9f,\\"%r[0:3]
-                    print "  %14.9f, %14.9f, %14.9f,\\"%r[4:7]
-                    print "  %14.9f, %14.9f, %14.9f,\\"%r[8:11]
-                    print "  %14.9f, %14.9f, %14.9f,\\"%r[16:19]
-                    print "  %14.9f, %14.9f, %14.9f,\\"%r[19:22]
-                    print "  %14.9f, %14.9f, %14.9f )"%r[22:25]
-                    print "### cut above here and paste into script ###"
+                    print("### cut below here and paste into script ###")
+                    print("set_view (\\")
+                    print("  %14.9f, %14.9f, %14.9f,\\"%r[0:3])
+                    print("  %14.9f, %14.9f, %14.9f,\\"%r[4:7])
+                    print("  %14.9f, %14.9f, %14.9f,\\"%r[8:11])
+                    print("  %14.9f, %14.9f, %14.9f,\\"%r[16:19])
+                    print("  %14.9f, %14.9f, %14.9f,\\"%r[19:22])
+                    print("  %14.9f, %14.9f, %14.9f )"%r[22:25])
+                    print("### cut above here and paste into script ###")
             if output==3:
                 return ("set_view (\\\n"+
                   "  %14.9f, %14.9f, %14.9f,\\\n"%r[0:3] +
@@ -878,10 +806,10 @@ SEE ALSO
                 view = eval(re.sub(r"[^0-9,\-\)\(\.]","",view))
             except:
                 traceback.print_exc()
-                print "Error: bad view argument; should be a sequence of 18 floats."
+                print("Error: bad view argument; should be a sequence of 18 floats.")
                 raise QuietException
         if len(view)!=18:
-            print "Error: bad view argument; should be a sequence of 18 floats."
+            print("Error: bad view argument; should be a sequence of 18 floats.")
             raise QuietException
         else:
             try:
@@ -944,8 +872,8 @@ SEE ALSO
                 pymol._view_dict = {}
                 pymol._view_dict_sc = Shortcut(pymol._view_dict.keys())                        
             else:
-                print " view: stored views:"
-                lst = pymol._view_dict.keys()
+                print(" view: stored views:")
+                lst = list(pymol._view_dict.keys())
                 lst.sort()
                 parsing.dump_str_list(lst)
                 
@@ -955,19 +883,19 @@ SEE ALSO
                 key = pymol._view_dict_sc.auto_err(key,'view')
                 _self.set_view(pymol._view_dict[key],animate=animate)
                 if _feedback(fb_module.scene,fb_mask.actions,_self): # redundant
-                    print " view: \"%s\" recalled."%key
+                    print(" view: \"%s\" recalled."%key)
             elif (action=='store') or (action=='update'):
                 pymol._view_dict_sc.append(key)
                 pymol._view_dict[key]=_self.get_view(0)
                 if _feedback(fb_module.scene,fb_mask.actions,_self):
-                    print " view: view "+action+"d as \"%s\"."%key
+                    print(" view: view "+action+"d as \"%s\"."%key)
             elif action=='clear':
                 key = pymol._view_dict_sc.auto_err(key,'view')
-                if pymol._view_dict.has_key(key):
+                if key in pymol._view_dict:
                     del pymol._view_dict[key]
                     pymol._view_dict_sc = Shortcut(pymol._view_dict.keys())            
                     if _feedback(fb_module.scene,fb_mask.actions,_self): # redundant
-                        print " view: '%s' deleted."%key
+                        print(" view: '%s' deleted."%key)
 
 
     def get_viewport(output=1, quiet=1, _self=cmd):
@@ -1009,15 +937,15 @@ PYMOL API
             if len(r):
                 if (_self.get_setting_int("logging") != 0) and (output<3):
                     if not quiet:
-                        print " get_viewport: data written to log file."
+                        print(" get_viewport: data written to log file.")
                     _self.log("_ viewport (\\\n","cmd.viewport((\\\n")
                     _self.log("_  %14.9f, %14.9f )\n"% r)
                     if output<2: # suppress if we have a log file open
                         output=0
                 if output and (not quiet) and (output<3):
-                    print "### cut below here and paste into script ###"
-                    print "viewport %4d, %4d"% r
-                    print "### cut above here and paste into script ###"
+                    print("### cut below here and paste into script ###")
+                    print("viewport %4d, %4d"% r)
+                    print("### cut above here and paste into script ###")
             if output==3:
                 return ("viewport ( %14.9f, %14.9f )\n"% r)
         elif _self._raising(r,_self):
@@ -1151,7 +1079,7 @@ SEE ALSO
         '''
         wiz = _self.get_wizard()
         replace_flag = (wiz is not None
-                and str(wiz.__class__) == 'pymol.wizard.message.Message'
+                and wiz.__class__.__name__ == 'Message'
                 and hasattr(wiz, 'from_scene'))
 
         if message:
@@ -1167,7 +1095,7 @@ SEE ALSO
 
     def scene(key='auto', action='recall', message=None, view=1,
               color=1, active=1, rep=1, frame=1, animate=-1,
-              new_key=None, hand=1, quiet=1, _self=cmd):
+              new_key=None, hand=1, quiet=1, sele="all", _self=cmd):
         '''
 DESCRIPTION
 
@@ -1246,7 +1174,7 @@ SEE ALSO
         with _self.lockcm:
             r = _cmd.scene(_self._COb, key, action, message, int(view),
                     int(color), int(active), int(rep), int(frame),
-                    float(animate), new_key, int(hand))
+                    float(animate), new_key, int(hand), sele)
 
         # autocomplete
         if action in ('store', 'delete') or action.startswith('insert_'):
@@ -1257,6 +1185,66 @@ SEE ALSO
 
         return r
                         
+    def _legacy_scene(key='auto', action='recall', message=None, view=1,
+              color=1, active=1, rep=1, frame=1, animate=-1,
+              new_key=None, hand=1, quiet=1, _self=cmd):
+        ''' FOR INTERNAL USE ONLY. Stores and deletes <=1.7.4 compatible scenes. '''
+        pymol=_self._pymol
+        r = DEFAULT_SUCCESS
+        view = int(view)
+        rep = int(rep)
+        color = int(color)
+        active = int(active)
+        frame = int(frame)
+        quiet = int(quiet)
+        animate = 0
+
+        try:
+            _self.lock(_self) # manipulating global data, so need lock
+            if key=='*':
+                if action=='clear':
+                    for key in pymol._scene_dict:
+                        # free selections
+                        scene_list = pymol._scene_dict[key]
+                        if len(scene_list)>3:
+                            colorection = scene_list[3]
+                            if colorection!=None:
+                                _self.del_colorection(colorection,key)
+                        name = "_scene_"+key+"_*"
+                        _self.delete(name)
+                else:
+                    raise ValueError('action=' + action)
+            else:
+                if action == 'store':
+                    if key in ('new', 'auto'):
+                        raise ValueError('key=' + key)
+                    if key in pymol._scene_dict:
+                        raise RuntimeError('update not supported')
+                    if rep:
+                        for rep_name in rep_list:
+                            name = "_scene_"+key+"_"+rep_name
+                            _self.select(name,"rep "+rep_name)
+                    if is_string(message):
+                        if message:
+                            if (message[0:1] in [ '"',"'"] and
+                                 message[-1:] in [ '"',"'"]):
+                                message=message[1:-1]
+                            else:
+                                message = message.splitlines()
+                    pymol._scene_dict[key] = [
+                        _self.get_view(0) if view else None,
+                        _self.get_vis() if active else None,
+                        _self.get_frame() if frame else None,
+                        _self.get_colorection(key) if color else None,
+                        1 if rep else None,
+                        message,
+                    ]
+                else:
+                    raise ValueError('action=' + action)
+        finally:
+            _self.unlock(r,_self)
+        return r
+
     def session_save_views(session,_self=cmd):
         pymol=_self._pymol        
         session['view_dict']=copy.deepcopy(pymol._view_dict)
@@ -1264,15 +1252,15 @@ SEE ALSO
 
     def session_restore_views(session,_self=cmd):
         pymol=_self._pymol
-        if session.has_key('view_dict'):
+        if 'view_dict' in session:
             pymol._view_dict=copy.deepcopy(session['view_dict'])
-            pymol._view_dict_sc.rebuild(pymol._view_dict.keys())
+            pymol._view_dict_sc.rebuild(list(pymol._view_dict.keys()))
         return 1
 
     def session_restore_scenes(session,_self=cmd):
         # Restore scenes from old session files (<= 1.7.4)
 
-        if session.has_key('scene_dict'):
+        if 'scene_dict' in session:
             _self.scene('*', 'clear')
 
             # save initial scene
@@ -1286,7 +1274,7 @@ SEE ALSO
                 _self.mstop()
                 frame = _self.get_frame()
 
-            for key, data in session['scene_dict'].items():
+            for key, data in list(session['scene_dict'].items()):
                 _convert_legacy_scene(key, data, _self)
 
             if frame:
@@ -1297,7 +1285,7 @@ SEE ALSO
             _self.scene(tempname, 'recall', animate=0)
             _self.scene(tempname, 'clear')
 
-        if session.has_key('scene_order'):
+        if 'scene_order' in session:
             _self.scene_order(' '.join(session['scene_order']))
 
         _self._pymol._scene_dict_sc.rebuild(_self.get_scene_list())
@@ -1376,7 +1364,7 @@ PYMOL API
                 toggle=1
             r = _cmd.stereo(_self._COb,toggle)
             if is_error(r):
-                print "Error: Selected stereo mode is not available."
+                print("Error: Selected stereo mode is not available.")
         finally:
             _self.unlock(r,_self);
         if _self._raising(r,_self): raise QuietException
@@ -1562,10 +1550,6 @@ USAGE
 
     window [ action [, x [, y [, width [, height ]]]]]
 
-NOTES
-    
-    This command is not fully implemented in MacPyMOL.
-
 PYMOL API
 
     cmd.window(string action, int x, int y, int width, int height)
@@ -1577,7 +1561,13 @@ PYMOL API
         r = DEFAULT_ERROR      
         try:
             _self.lock(_self)
-            r = _cmd.window(_self._COb,action,int(x),int(y),int(width),int(height))
+            from pymol.gui import get_qtwindow as getPyMOLWindow
+            qt_window = getPyMOLWindow()
+            if qt_window:
+                r = DEFAULT_SUCCESS
+                qt_window.window_cmd(action, int(x),int(y),int(width),int(height))
+            else:
+                r = _cmd.window(_self._COb,action,int(x),int(y),int(width),int(height))
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise QuietException
@@ -1598,18 +1588,10 @@ PYMOL API
     cmd.viewport(int width, int height)
         '''
         r = None
-        if cmd.is_string(width) and height < 0:
-            try:
-                width = eval(re.sub(r"[^0-9,\-\)\(\.]","",width))
-            except:
-                traceback.print_exc()
-                print "Error: bad viewport argument; should be 2 floats, width and height."
-                raise QuietException
-            if len(width)!=2:
-                print "Error: bad viewport argument; should be 2 floats, width and height."
-                raise QuietException
-            height = width[1]
-            width = width[0]
+        if cmd.is_string(width) and height == -1:
+            width = _self.safe_eval(width)
+            if _self.is_sequence(width):
+                width, height = width
 
         if not cmd.is_glut_thread():
             _self.do("viewport %d,%d"%(int(width),int(height)),0)
@@ -1677,6 +1659,7 @@ PYMOL API
         'arrow'       : 5,
         'dumbbell'    : 6,
         'putty'       : 7,
+        'dash'        : 8,
     }
 
     cartoon_sc = Shortcut(cartoon_dict.keys())
@@ -1810,7 +1793,7 @@ SEE ALSO
         return r
 
     def ray(width=0, height=0, antialias=-1, angle=0.0, shift=0.0,
-            renderer=-1, quiet=1, async=0, _self=cmd):
+            renderer=-1, quiet=1, async_=0, _self=cmd, **kwargs):
         '''
 DESCRIPTION
 
@@ -1872,6 +1855,11 @@ SEE ALSO
 
     draw, png, save
         '''
+        async_ = int(kwargs.pop('async', async_))
+
+        if kwargs:
+            raise pymol.CmdException('unknown argument: ' + ', '.join(kwargs))
+
         arg_tup = (int(width),int(height),
                    int(antialias),float(angle),
                    float(shift),int(renderer),int(quiet),_self)
@@ -1884,8 +1872,8 @@ SEE ALSO
             _self.rock(0)
         #
         r = DEFAULT_ERROR
-        if not async:
-            r = apply(_ray, arg_tup)
+        if not async_:
+            r = _ray(*arg_tup)
         else:
             render_thread = threading.Thread(target=_ray, args=arg_tup)
             render_thread.setDaemon(1)
@@ -1923,7 +1911,7 @@ SEE ALSO
         else:
             try:
                 _self.lock(_self)
-                r = _self._do("_ cmd._refresh(_self=cmd)",_self=_self)
+                r = _self._do("_ cmd._refresh()")
             finally:
                 _self.unlock(r,_self)
         if _self._raising(r,_self): raise QuietException
@@ -2172,7 +2160,7 @@ DESCRIPTION
                 'resi': 'resv'}.get(expression, expression)
 
         if expression == 'count':
-            e_list = range(_self.count_atoms(selection))
+            e_list = list(range(_self.count_atoms(selection)))
         else:
             e_list = []
             _self.iterate(selection, 'e_list.append(%s)' % (expression), space=locals())
@@ -2181,8 +2169,8 @@ DESCRIPTION
             v_list = [float(v) for v in e_list if v is not None]
         except (TypeError, ValueError):
             if not quiet:
-                print ' Spectrum: Expression is non-numeric, enumerating values'
-            v_list = e_list = map(sorted(set(e_list)).index, e_list)
+                print(' Spectrum: Expression is non-numeric, enumerating values')
+            v_list = e_list = list(map(sorted(set(e_list)).index, e_list))
 
         if not v_list:
             return (0., 0.)
@@ -2191,7 +2179,7 @@ DESCRIPTION
         if maximum is None: maximum = max(v_list)
         r = minimum, maximum = float(minimum), float(maximum)
         if not quiet:
-            print ' Spectrum: range (%.5f to %.5f)' % r
+            print(' Spectrum: range (%.5f to %.5f)' % r)
 
         val_range = maximum - minimum
         if not val_range:
@@ -2200,7 +2188,7 @@ DESCRIPTION
 
         e_it = iter(e_list)
         def next_color():
-            v = e_it.next()
+            v = next(e_it)
             if v is None:
                 return False
             v = min(1.0, max(0.0, (float(v) - minimum) / val_range)) * (n_colors - 1)
@@ -2283,7 +2271,7 @@ PYMOL API
         if palette_hit:
             palette = palette_hit
 
-        if expression not in ('count', 'b', 'q', 'pc') or not palette_hit:
+        if not expression.replace('_', '').isalpha() or not palette_hit:
             return spectrumany(expression, palette, selection,
                     minimum, maximum, quiet, _self)
         
@@ -2351,10 +2339,10 @@ PYMOL API
         r = DEFAULT_ERROR
         if _self.is_string(rgb):
             rgb = safe_list_eval(rgb)
-        if not (isinstance(rgb,types.ListType) or isinstance(rgb,types.TupleType)):
-            print "Error: color specification must be a list such as [ 1.0, 0.0, 0.0 ]"
+        if not (isinstance(rgb,list) or isinstance(rgb,tuple)):
+            print("Error: color specification must be a list such as [ 1.0, 0.0, 0.0 ]")
         elif len(rgb)!=3:
-            print "Error: color specification must be a list such as [ 1.0, 0.0, 0.0 ]"
+            print("Error: color specification must be a list such as [ 1.0, 0.0, 0.0 ]")
         else:
             rgb = [float(rgb[0]),float(rgb[1]),float(rgb[2])]
             if (rgb[0]>1.0) or (rgb[1]>1.0) or (rgb[2]>1.0):
@@ -2368,7 +2356,7 @@ PYMOL API
                     r = _cmd.colordef(_self._COb,str(name),rgb[0],rgb[1],rgb[2],int(mode),int(quiet))
                     _self._invalidate_color_sc(_self)
                 else:
-                    print "Error: invalid color."
+                    print("Error: invalid color.")
             finally:
                 _self.unlock(r,_self)
         if _self._raising(r,_self): raise QuietException
@@ -2382,5 +2370,5 @@ PYMOL API
     recolour = recolor
     
 
-    import setting
+    from . import setting
     
